Change in osmo-bts[master]: Rename osmo dyn ts enums to contain SDCCH8

This is merely a historical archive of years 2008-2021, before the migration to mailman3.

A maintained and still updated list archive can be found at https://lists.osmocom.org/hyperkitty/list/gerrit-log@lists.osmocom.org/.

pespin gerrit-no-reply at lists.osmocom.org
Mon Jul 5 08:03:08 UTC 2021


pespin has submitted this change. ( https://gerrit.osmocom.org/c/osmo-bts/+/24799 )

Change subject: Rename osmo dyn ts enums to contain SDCCH8
......................................................................

Rename osmo dyn ts enums to contain SDCCH8

They will gain support to be activated as SDCCH/8 soon too.

Related: SYS#5309
Depends: libosmocore.git I56dcfe4d17899630b17f80145c3ced72f1e91e68
Change-Id: Ia617d20fc52f09dbab8f4516c06fa1efac08e898
---
M doc/manuals/abis/rsl.adoc
M src/common/gsm_data.c
M src/common/lchan.c
M src/common/oml.c
M src/common/pcu_sock.c
M src/common/rsl.c
M src/common/vty.c
M src/osmo-bts-lc15/l1_if.c
M src/osmo-bts-lc15/oml.c
M src/osmo-bts-oc2g/l1_if.c
M src/osmo-bts-oc2g/oml.c
M src/osmo-bts-octphy/l1_if.c
M src/osmo-bts-octphy/l1_oml.c
M src/osmo-bts-sysmo/l1_if.c
M src/osmo-bts-sysmo/oml.c
M src/osmo-bts-trx/l1_if.c
16 files changed, 52 insertions(+), 52 deletions(-)

Approvals:
  laforge: Looks good to me, but someone else must approve
  fixeria: Looks good to me, approved
  Jenkins Builder: Verified



diff --git a/doc/manuals/abis/rsl.adoc b/doc/manuals/abis/rsl.adoc
index b4c2609..6d8cd36 100644
--- a/doc/manuals/abis/rsl.adoc
+++ b/doc/manuals/abis/rsl.adoc
@@ -123,7 +123,7 @@
 ==== Channel Activation
 
 When used on a timeslot using the non-standard channel combination
-'NM_CHANC_OSMO_TCHFull_TCHHalf_PDCH' as configured by OML, the regular
+'NM_CHANC_OSMO_DYN' as configured by OML, the regular
 RSL channel activation procedures can not only be used for activation
 of circuit-switched channels, but also for activation of a PDCH.
 
@@ -417,7 +417,7 @@
 ==== Osmocom Style Dynamic Channels
 
 This method is in use when OML uses
-'NM_CHANC_OSMO_TCHFull_TCHHalf_PDCH' (0x90) for the given time-slot.
+'NM_CHANC_OSMO_DYN' (0x90) for the given time-slot.
 
 The activation of PDCH is performed by using the regular 'RSL CHANNEL ACTIVATE'
 procedure according to <<CHANNEL_ACTIVATION>>, with these modifications:
diff --git a/src/common/lchan.c b/src/common/lchan.c
index 9e98166..5a3f539 100644
--- a/src/common/lchan.c
+++ b/src/common/lchan.c
@@ -40,7 +40,7 @@
 	case GSM_PCHAN_TCH_F_PDCH:
 		return (ts->flags & TS_F_PDCH_ACTIVE)
 		       && !(ts->flags & TS_F_PDCH_PENDING_MASK);
-	case GSM_PCHAN_TCH_F_TCH_H_PDCH:
+	case GSM_PCHAN_OSMO_DYN:
 		return ts->dyn.pchan_is == GSM_PCHAN_PDCH
 		       && ts->dyn.pchan_want == ts->dyn.pchan_is;
 	default:
diff --git a/src/common/oml.c b/src/common/oml.c
index aeded8b..819b033 100644
--- a/src/common/oml.c
+++ b/src/common/oml.c
@@ -802,7 +802,7 @@
 						    : GSM_PCHAN_TCH_F;
 
 	/* Osmocom RSL CHAN ACT style dyn TS */
-	if (pchan == GSM_PCHAN_TCH_F_TCH_H_PDCH) {
+	if (pchan == GSM_PCHAN_OSMO_DYN) {
 		pchan = ts->dyn.pchan_is;
 
 		/* If the dyn TS doesn't have a pchan yet, do nothing. */
diff --git a/src/common/pcu_sock.c b/src/common/pcu_sock.c
index f40dd42..41a5ffc 100644
--- a/src/common/pcu_sock.c
+++ b/src/common/pcu_sock.c
@@ -99,7 +99,7 @@
 			return !(ts->flags & TS_F_PDCH_DEACT_PENDING);
 		else
 			return (ts->flags & TS_F_PDCH_ACT_PENDING);
-	case GSM_PCHAN_TCH_F_TCH_H_PDCH:
+	case GSM_PCHAN_OSMO_DYN:
 		/*
 		 * When we're busy de-/activating the PDCH, we first set
 		 * ts->dyn.pchan_want, tell the PCU about it and wait for a
@@ -867,7 +867,7 @@
 		     gsm_lchant_name(lchan->type));
 		return -EINVAL;
 	}
-	if (lchan->ts->pchan == GSM_PCHAN_TCH_F_TCH_H_PDCH &&
+	if (lchan->ts->pchan == GSM_PCHAN_OSMO_DYN &&
 	    lchan->ts->dyn.pchan_is != GSM_PCHAN_PDCH) {
 		LOGP(DPCU, LOGL_ERROR,
 		     "%s request, but lchan in dyn TS is not configured as PDCH in lower layers (is %s)\n",
diff --git a/src/common/rsl.c b/src/common/rsl.c
index 010b9d3..8043f98 100644
--- a/src/common/rsl.c
+++ b/src/common/rsl.c
@@ -1132,7 +1132,7 @@
 
 	case LCHAN_REL_ACT_PCU:
 		switch (lchan->ts->pchan) {
-		case GSM_PCHAN_TCH_F_TCH_H_PDCH:
+		case GSM_PCHAN_OSMO_DYN:
 			if (lchan->ts->dyn.pchan_is != GSM_PCHAN_PDCH) {
 				LOGP(DRSL, LOGL_ERROR, "%s (ss=%d) PDCH release: not in PDCH mode\n",
 				     gsm_ts_and_pchan_name(lchan->ts), lchan->nr);
@@ -1140,7 +1140,7 @@
 			}
 			if (lchan->ts->dyn.pchan_want != GSM_PCHAN_PDCH) {
 				/* Continue to ack the release below. (This is a non-standard rel ack invented
-				 * specifically for GSM_PCHAN_TCH_F_TCH_H_PDCH). */
+				 * specifically for GSM_PCHAN_OSMO_DYN). */
 				/* remember the fact that the TS is now released */
 				lchan->ts->dyn.pchan_is = GSM_PCHAN_NONE;
 				send_rel_ack = true;
@@ -1502,7 +1502,7 @@
 		return rsl_tx_chan_act_nack(lchan, RSL_ERR_EQUIPMENT_FAIL);
 	}
 
-	if (ts->pchan == GSM_PCHAN_TCH_F_TCH_H_PDCH) {
+	if (ts->pchan == GSM_PCHAN_OSMO_DYN) {
 		ts->dyn.pchan_want = dyn_pchan_from_chan_nr(dch->chan_nr);
 		DEBUGP(DRSL, "%s rx chan activ\n", gsm_ts_and_pchan_name(ts));
 
@@ -1711,7 +1711,7 @@
 		  gsm48_chan_mode_name(lchan->tch_mode));
 
 	/* Connecting PDCH on dyn TS goes via PCU instead. */
-	if (ts->pchan == GSM_PCHAN_TCH_F_TCH_H_PDCH
+	if (ts->pchan == GSM_PCHAN_OSMO_DYN
 	    && ts->dyn.pchan_want == GSM_PCHAN_PDCH) {
 		/*
 		 * We ack the activation to the BSC right away, regardless of
@@ -1851,7 +1851,7 @@
 	lchan->rel_act_kind = LCHAN_REL_ACT_RSL;
 
 	/* Dynamic channel in PDCH mode is released via PCU */
-	if (lchan->ts->pchan == GSM_PCHAN_TCH_F_TCH_H_PDCH
+	if (lchan->ts->pchan == GSM_PCHAN_OSMO_DYN
 	    && lchan->ts->dyn.pchan_is == GSM_PCHAN_PDCH) {
 		rc = dyn_ts_pdch_release(lchan);
 		if (rc == 1) {
@@ -3032,7 +3032,7 @@
 	switch (ts->pchan) {
 	case GSM_PCHAN_TCH_F_PDCH:
 		return ipacc_dyn_pdch_ts_disconnected(ts);
-	case GSM_PCHAN_TCH_F_TCH_H_PDCH:
+	case GSM_PCHAN_OSMO_DYN:
 		return osmo_dyn_ts_disconnected(ts);
 	default:
 		return;
@@ -3130,7 +3130,7 @@
 	switch (ts->pchan) {
 	case GSM_PCHAN_TCH_F_PDCH:
 		return ipacc_dyn_pdch_ts_connected(ts, rc);
-	case GSM_PCHAN_TCH_F_TCH_H_PDCH:
+	case GSM_PCHAN_OSMO_DYN:
 		return osmo_dyn_ts_connected(ts, rc);
 	default:
 		return;
diff --git a/src/common/vty.c b/src/common/vty.c
index 10e1748..3065a90 100644
--- a/src/common/vty.c
+++ b/src/common/vty.c
@@ -1541,7 +1541,7 @@
 static void vty_out_dyn_ts_status(struct vty *vty, const struct gsm_bts_trx_ts *ts)
 {
 	switch (ts->pchan) {
-	case GSM_PCHAN_TCH_F_TCH_H_PDCH:
+	case GSM_PCHAN_OSMO_DYN:
 		if (ts->dyn.pchan_is == ts->dyn.pchan_want)
 			vty_out(vty, " as %s",
 				gsm_pchan_name(ts->dyn.pchan_is));
@@ -1690,7 +1690,7 @@
 		lchan->nr, gsm_lchant_name(lchan->type), VTY_NEWLINE);
 	/* show dyn TS details, if applicable */
 	switch (lchan->ts->pchan) {
-	case GSM_PCHAN_TCH_F_TCH_H_PDCH:
+	case GSM_PCHAN_OSMO_DYN:
 		vty_out(vty, "  Osmocom Dyn TS:");
 		vty_out_dyn_ts_status(vty, lchan->ts);
 		vty_out(vty, VTY_NEWLINE);
diff --git a/src/osmo-bts-lc15/l1_if.c b/src/osmo-bts-lc15/l1_if.c
index b7c24c0..02c8646 100644
--- a/src/osmo-bts-lc15/l1_if.c
+++ b/src/osmo-bts-lc15/l1_if.c
@@ -682,7 +682,7 @@
 		if (ts->flags & TS_F_PDCH_ACTIVE)
 			return GSM_PCHAN_PDCH;
 		return GSM_PCHAN_TCH_F;
-	case GSM_PCHAN_TCH_F_TCH_H_PDCH:
+	case GSM_PCHAN_OSMO_DYN:
 		return ts->dyn.pchan_is;
 	default:
 		return ts->pchan;
@@ -696,7 +696,7 @@
 	uint8_t cbits = 0;
 	enum gsm_phys_chan_config pchan = pick_pchan(ts);
 	OSMO_ASSERT(pchan != GSM_PCHAN_TCH_F_PDCH);
-	OSMO_ASSERT(pchan != GSM_PCHAN_TCH_F_TCH_H_PDCH);
+	OSMO_ASSERT(pchan != GSM_PCHAN_OSMO_DYN);
 
 	switch (sapi) {
 	case GsmL1_Sapi_Bcch:
diff --git a/src/osmo-bts-oc2g/l1_if.c b/src/osmo-bts-oc2g/l1_if.c
index 475edd2..2cefc3b 100644
--- a/src/osmo-bts-oc2g/l1_if.c
+++ b/src/osmo-bts-oc2g/l1_if.c
@@ -735,7 +735,7 @@
 		if (ts->flags & TS_F_PDCH_ACTIVE)
 			return GSM_PCHAN_PDCH;
 		return GSM_PCHAN_TCH_F;
-	case GSM_PCHAN_TCH_F_TCH_H_PDCH:
+	case GSM_PCHAN_OSMO_DYN:
 		return ts->dyn.pchan_is;
 	default:
 		return ts->pchan;
@@ -749,7 +749,7 @@
 	uint8_t cbits = 0;
 	enum gsm_phys_chan_config pchan = pick_pchan(ts);
 	OSMO_ASSERT(pchan != GSM_PCHAN_TCH_F_PDCH);
-	OSMO_ASSERT(pchan != GSM_PCHAN_TCH_F_TCH_H_PDCH);
+	OSMO_ASSERT(pchan != GSM_PCHAN_OSMO_DYN);
 
 	switch (sapi) {
 	case GsmL1_Sapi_Bcch:
diff --git a/src/osmo-bts-octphy/l1_if.c b/src/osmo-bts-octphy/l1_if.c
index f69a535..294a65e 100644
--- a/src/osmo-bts-octphy/l1_if.c
+++ b/src/osmo-bts-octphy/l1_if.c
@@ -329,7 +329,7 @@
 		if (ts->flags & TS_F_PDCH_ACTIVE)
 			return GSM_PCHAN_PDCH;
 		return GSM_PCHAN_TCH_F;
-	case GSM_PCHAN_TCH_F_TCH_H_PDCH:
+	case GSM_PCHAN_OSMO_DYN:
 		return ts->dyn.pchan_is;
 	default:
 		return ts->pchan;
@@ -344,7 +344,7 @@
 	enum gsm_phys_chan_config pchan = pick_pchan(ts);
 
 	OSMO_ASSERT(pchan != GSM_PCHAN_TCH_F_PDCH);
-	OSMO_ASSERT(pchan != GSM_PCHAN_TCH_F_TCH_H_PDCH);
+	OSMO_ASSERT(pchan != GSM_PCHAN_OSMO_DYN);
 
 	switch (sapi) {
 	case cOCTVC1_GSM_SAPI_ENUM_BCCH:
diff --git a/src/osmo-bts-octphy/l1_oml.c b/src/osmo-bts-octphy/l1_oml.c
index acd43e4..5b48b2e 100644
--- a/src/osmo-bts-octphy/l1_oml.c
+++ b/src/osmo-bts-octphy/l1_oml.c
@@ -1832,7 +1832,7 @@
 {
 	int rc;
 	if (as_pchan == GSM_PCHAN_TCH_F_PDCH
-	    || as_pchan == GSM_PCHAN_TCH_F_TCH_H_PDCH) {
+	    || as_pchan == GSM_PCHAN_OSMO_DYN) {
 		LOGP(DL1C, LOGL_ERROR,
 		     "%s Requested TS connect as %s,"
 		     " expected a specific pchan instead\n",
diff --git a/src/osmo-bts-sysmo/l1_if.c b/src/osmo-bts-sysmo/l1_if.c
index 07f36db..5c99824 100644
--- a/src/osmo-bts-sysmo/l1_if.c
+++ b/src/osmo-bts-sysmo/l1_if.c
@@ -683,7 +683,7 @@
 		if (ts->flags & TS_F_PDCH_ACTIVE)
 			return GSM_PCHAN_PDCH;
 		return GSM_PCHAN_TCH_F;
-	case GSM_PCHAN_TCH_F_TCH_H_PDCH:
+	case GSM_PCHAN_OSMO_DYN:
 		return ts->dyn.pchan_is;
 	default:
 		return ts->pchan;
@@ -697,7 +697,7 @@
 	uint8_t cbits = 0;
 	enum gsm_phys_chan_config pchan = pick_pchan(ts);
 	OSMO_ASSERT(pchan != GSM_PCHAN_TCH_F_PDCH);
-	OSMO_ASSERT(pchan != GSM_PCHAN_TCH_F_TCH_H_PDCH);
+	OSMO_ASSERT(pchan != GSM_PCHAN_OSMO_DYN);
 
 	switch (sapi) {
 	case GsmL1_Sapi_Bcch:
diff --git a/src/osmo-bts-trx/l1_if.c b/src/osmo-bts-trx/l1_if.c
index 3be5179..754e9d7 100644
--- a/src/osmo-bts-trx/l1_if.c
+++ b/src/osmo-bts-trx/l1_if.c
@@ -281,7 +281,7 @@
 	/* set physical channel. For dynamic timeslots, the caller should have
 	 * decided on a more specific PCHAN type already. */
 	OSMO_ASSERT(pchan != GSM_PCHAN_TCH_F_PDCH);
-	OSMO_ASSERT(pchan != GSM_PCHAN_TCH_F_TCH_H_PDCH);
+	OSMO_ASSERT(pchan != GSM_PCHAN_OSMO_DYN);
 	rc = trx_sched_set_pchan(ts, pchan);
 	if (rc)
 		return NM_NACK_RES_NOTAVAIL;
@@ -322,7 +322,7 @@
 		pchan = (ts->flags & TS_F_PDCH_ACTIVE)? GSM_PCHAN_PDCH
 			                              : GSM_PCHAN_TCH_F;
 		break;
-	case GSM_PCHAN_TCH_F_TCH_H_PDCH:
+	case GSM_PCHAN_OSMO_DYN:
 		OSMO_ASSERT(ts->dyn.pchan_is == ts->dyn.pchan_want);
 		pchan = ts->dyn.pchan_is;
 		break;

diff --git a/src/common/gsm_data.c b/src/common/gsm_data.c
index f533fb9..a6b0d7e 100644
--- a/src/common/gsm_data.c
+++ b/src/common/gsm_data.c
@@ -52,7 +52,7 @@
 	{ GSM_PCHAN_UNKNOWN,	"UNKNOWN" },
 	{ GSM_PCHAN_CCCH_SDCCH4_CBCH, "CCCH+SDCCH4+CBCH" },
 	{ GSM_PCHAN_SDCCH8_SACCH8C_CBCH, "SDCCH8+CBCH" },
-	{ GSM_PCHAN_TCH_F_TCH_H_PDCH, "TCH/F_TCH/H_PDCH" },
+	{ GSM_PCHAN_OSMO_DYN, "TCH/F_TCH/H_SDCCH8_PDCH" },
 	{ 0,			NULL }
 };
 
@@ -69,7 +69,7 @@
 	{ GSM_PCHAN_UNKNOWN,	"Unknown / Unsupported channel combination" },
 	{ GSM_PCHAN_CCCH_SDCCH4_CBCH, "FCCH + SCH + BCCH + CCCH + CBCH + 3 SDCCH + 2 SACCH (Comb. V)" },
 	{ GSM_PCHAN_SDCCH8_SACCH8C_CBCH, "7 SDCCH + 4 SACCH + CBCH (Comb. VII)" },
-	{ GSM_PCHAN_TCH_F_TCH_H_PDCH, "Dynamic TCH/F or TCH/H or GPRS PDCH" },
+	{ GSM_PCHAN_OSMO_DYN, "Dynamic TCH/F or TCH/H or SDCCH/8 or GPRS PDCH" },
 	{ 0,			NULL }
 };
 
@@ -115,7 +115,7 @@
 char *gsm_ts_and_pchan_name(const struct gsm_bts_trx_ts *ts)
 {
 	switch (ts->pchan) {
-	case GSM_PCHAN_TCH_F_TCH_H_PDCH:
+	case GSM_PCHAN_OSMO_DYN:
 		if (ts->dyn.pchan_is == ts->dyn.pchan_want)
 			snprintf(ts2str, sizeof(ts2str),
 				 "(" GSM_TS_NAME_FMT ",pchan=%s as %s)",
@@ -176,7 +176,7 @@
 {
 	uint8_t cbits, chan_nr;
 
-	OSMO_ASSERT(pchan != GSM_PCHAN_TCH_F_TCH_H_PDCH);
+	OSMO_ASSERT(pchan != GSM_PCHAN_OSMO_DYN);
 	OSMO_ASSERT(pchan != GSM_PCHAN_TCH_F_PDCH);
 
 	switch (pchan) {
@@ -243,7 +243,7 @@
 	uint8_t chan_nr;
 
 	switch (lchan->ts->pchan) {
-	case GSM_PCHAN_TCH_F_TCH_H_PDCH:
+	case GSM_PCHAN_OSMO_DYN:
 		/* Return chan_nr reflecting the current TS pchan, either a standard TCH kind, or the
 		 * nonstandard value reflecting PDCH for Osmocom style dyn TS. */
 		chan_nr = gsm_lchan_as_pchan2chan_nr(lchan, lchan->ts->dyn.pchan_is);
@@ -269,7 +269,7 @@
 uint8_t gsm_lchan_as_pchan2chan_nr(const struct gsm_lchan *lchan,
 				   enum gsm_phys_chan_config as_pchan)
 {
-	if (lchan->ts->pchan == GSM_PCHAN_TCH_F_TCH_H_PDCH
+	if (lchan->ts->pchan == GSM_PCHAN_OSMO_DYN
 	    && as_pchan == GSM_PCHAN_PDCH)
 		return RSL_CHAN_OSMO_PDCH | (lchan->ts->nr & ~RSL_CHAN_NR_MASK);
 	return gsm_pchan2chan_nr(as_pchan, lchan->ts->nr, lchan->nr);
@@ -347,7 +347,7 @@
 		if (ts->pchan != GSM_PCHAN_TCH_F &&
 		    ts->pchan != GSM_PCHAN_PDCH &&
 		    ts->pchan != GSM_PCHAN_TCH_F_PDCH &&
-		    ts->pchan != GSM_PCHAN_TCH_F_TCH_H_PDCH)
+		    ts->pchan != GSM_PCHAN_OSMO_DYN)
 			ok = false;
 		break;
 	case ABIS_RSL_CHAN_NR_CBITS_OSMO_VAMOS_Lm_ACCHs(0):
@@ -360,7 +360,7 @@
 	case ABIS_RSL_CHAN_NR_CBITS_Lm_ACCHs(1):
 		lch_idx = cbits & 0x1;	/* TCH/H */
 		if (ts->pchan != GSM_PCHAN_TCH_H &&
-		    ts->pchan != GSM_PCHAN_TCH_F_TCH_H_PDCH)
+		    ts->pchan != GSM_PCHAN_OSMO_DYN)
 			ok = false;
 		break;
 	case ABIS_RSL_CHAN_NR_CBITS_SDCCH4_ACCH(0):
@@ -397,7 +397,7 @@
 		break;
 	case ABIS_RSL_CHAN_NR_CBITS_OSMO_PDCH:
 		lch_idx = 0;
-		if (ts->pchan != GSM_PCHAN_TCH_F_TCH_H_PDCH)
+		if (ts->pchan != GSM_PCHAN_OSMO_DYN)
 			ok = false;
 		break;
 	default:
@@ -421,7 +421,7 @@
 	[GSM_PCHAN_CCCH_SDCCH4_CBCH] = 4,
 	[GSM_PCHAN_SDCCH8_SACCH8C_CBCH] = 8,
 	/*
 	 * GSM_PCHAN_TCH_F_PDCH and GSM_PCHAN_TCH_F_TCH_H_PDCH should not be
 	 * part of this, those TS are handled according to their dynamic state.
 	 */
 };
@@ -430,7 +430,7 @@
 enum gsm_phys_chan_config ts_pchan(const struct gsm_bts_trx_ts *ts)
 {
 	switch (ts->pchan) {
-	case GSM_PCHAN_TCH_F_TCH_H_PDCH:
+	case GSM_PCHAN_OSMO_DYN:
 		return ts->dyn.pchan_is;
 	case GSM_PCHAN_TCH_F_PDCH:
 		if (ts->flags & TS_F_PDCH_ACTIVE)
@@ -421,7 +421,7 @@
 	[GSM_PCHAN_SDCCH8_SACCH8C_CBCH] = 8,
 	/*
-	 * GSM_PCHAN_TCH_F_PDCH and GSM_PCHAN_TCH_F_TCH_H_PDCH should not be
+	 * GSM_PCHAN_TCH_F_PDCH and GSM_PCHAN_OSMO_DYN should not be
 	 * part of this, those TS are handled according to their dynamic state.
 	 */
diff --git a/src/osmo-bts-lc15/oml.c b/src/osmo-bts-lc15/oml.c
index acce1d4..b4945be 100644
--- a/src/osmo-bts-lc15/oml.c
+++ b/src/osmo-bts-lc15/oml.c
@@ -93,7 +93,7 @@
 	[GSM_PCHAN_PDCH]		= GsmL1_LogChComb_XIII,
 	[GSM_PCHAN_UNKNOWN]		= GsmL1_LogChComb_0,
 	/*
 	 * GSM_PCHAN_TCH_F_PDCH and GSM_PCHAN_TCH_F_TCH_H_PDCH should not be
 	 * part of this, only "real" pchan values will be looked up here.
 	 * See the callers of ts_connect_as().
 	 */
@@ -525,7 +525,7 @@
 	GsmL1_MphConnectReq_t *cr;
 
 	if (pchan == GSM_PCHAN_TCH_F_PDCH
-	    || pchan == GSM_PCHAN_TCH_F_TCH_H_PDCH) {
+	    || pchan == GSM_PCHAN_OSMO_DYN) {
 		LOGP(DL1C, LOGL_ERROR,
 		     "%s Requested TS connect as %s,"
 		     " expected a specific pchan instead\n",
@@ -545,7 +545,7 @@
 {
 	enum gsm_phys_chan_config pchan = ts->pchan;
 	switch (pchan) {
-	case GSM_PCHAN_TCH_F_TCH_H_PDCH:
+	case GSM_PCHAN_OSMO_DYN:
 		ts->dyn.pchan_is = ts->dyn.pchan_want = GSM_PCHAN_NONE;
 		/* First connect as NONE, until first RSL CHAN ACT. */
 		pchan = GSM_PCHAN_NONE;
@@ -580,7 +580,7 @@
 {
 	enum gsm_phys_chan_config pchan = lchan->ts->pchan;
 
-	if (pchan == GSM_PCHAN_TCH_F_TCH_H_PDCH)
+	if (pchan == GSM_PCHAN_OSMO_DYN)
 		pchan = lchan->ts->dyn.pchan_want;
 
 	switch (pchan) {
@@ -599,7 +599,7 @@
 	case GSM_PCHAN_PDCH:
 	case GSM_PCHAN_UNKNOWN:
 	default:
 	/* case GSM_PCHAN_TCH_F_TCH_H_PDCH: is caught above */
 		return GsmL1_SubCh_NA;
 	}
 
@@ -93,7 +93,7 @@
 	[GSM_PCHAN_UNKNOWN]		= GsmL1_LogChComb_0,
 	/*
-	 * GSM_PCHAN_TCH_F_PDCH and GSM_PCHAN_TCH_F_TCH_H_PDCH should not be
+	 * GSM_PCHAN_TCH_F_PDCH and GSM_PCHAN_OSMO_DYN should not be
 	 * part of this, only "real" pchan values will be looked up here.
 	 * See the callers of ts_connect_as().
@@ -599,7 +599,7 @@
 	case GSM_PCHAN_UNKNOWN:
 	default:
-	/* case GSM_PCHAN_TCH_F_TCH_H_PDCH: is caught above */
+	/* case GSM_PCHAN_OSMO_DYN: is caught above */
 		return GsmL1_SubCh_NA;
 	}
diff --git a/src/osmo-bts-oc2g/oml.c b/src/osmo-bts-oc2g/oml.c
index 5646cfb..9791ab8 100644
--- a/src/osmo-bts-oc2g/oml.c
+++ b/src/osmo-bts-oc2g/oml.c
@@ -93,7 +93,7 @@
 	[GSM_PCHAN_PDCH]		= GsmL1_LogChComb_XIII,
 	[GSM_PCHAN_UNKNOWN]		= GsmL1_LogChComb_0,
 	/*
 	 * GSM_PCHAN_TCH_F_PDCH and GSM_PCHAN_TCH_F_TCH_H_PDCH should not be
 	 * part of this, only "real" pchan values will be looked up here.
 	 * See the callers of ts_connect_as().
 	 */
@@ -540,7 +540,7 @@
 	GsmL1_MphConnectReq_t *cr;
 
 	if (pchan == GSM_PCHAN_TCH_F_PDCH
-	    || pchan == GSM_PCHAN_TCH_F_TCH_H_PDCH) {
+	    || pchan == GSM_PCHAN_OSMO_DYN) {
 		LOGP(DL1C, LOGL_ERROR,
 		     "%s Requested TS connect as %s,"
 		     " expected a specific pchan instead\n",
@@ -560,7 +560,7 @@
 {
 	enum gsm_phys_chan_config pchan = ts->pchan;
 	switch (pchan) {
-	case GSM_PCHAN_TCH_F_TCH_H_PDCH:
+	case GSM_PCHAN_OSMO_DYN:
 		ts->dyn.pchan_is = ts->dyn.pchan_want = GSM_PCHAN_NONE;
 		/* First connect as NONE, until first RSL CHAN ACT. */
 		pchan = GSM_PCHAN_NONE;
@@ -595,7 +595,7 @@
 {
 	enum gsm_phys_chan_config pchan = lchan->ts->pchan;
 
-	if (pchan == GSM_PCHAN_TCH_F_TCH_H_PDCH)
+	if (pchan == GSM_PCHAN_OSMO_DYN)
 		pchan = lchan->ts->dyn.pchan_want;
 
 	switch (pchan) {
@@ -614,7 +614,7 @@
 	case GSM_PCHAN_PDCH:
 	case GSM_PCHAN_UNKNOWN:
 	default:
 	/* case GSM_PCHAN_TCH_F_TCH_H_PDCH: is caught above */
 		return GsmL1_SubCh_NA;
 	}
 
@@ -93,7 +93,7 @@
 	[GSM_PCHAN_UNKNOWN]		= GsmL1_LogChComb_0,
 	/*
-	 * GSM_PCHAN_TCH_F_PDCH and GSM_PCHAN_TCH_F_TCH_H_PDCH should not be
+	 * GSM_PCHAN_TCH_F_PDCH and GSM_PCHAN_OSMO_DYN should not be
 	 * part of this, only "real" pchan values will be looked up here.
 	 * See the callers of ts_connect_as().
@@ -614,7 +614,7 @@
 	case GSM_PCHAN_UNKNOWN:
 	default:
-	/* case GSM_PCHAN_TCH_F_TCH_H_PDCH: is caught above */
+	/* case GSM_PCHAN_OSMO_DYN: is caught above */
 		return GsmL1_SubCh_NA;
 	}
diff --git a/src/osmo-bts-sysmo/oml.c b/src/osmo-bts-sysmo/oml.c
index 818d82b..93ecf90 100644
--- a/src/osmo-bts-sysmo/oml.c
+++ b/src/osmo-bts-sysmo/oml.c
@@ -90,7 +90,7 @@
 	[GSM_PCHAN_PDCH]		= GsmL1_LogChComb_XIII,
 	[GSM_PCHAN_UNKNOWN]		= GsmL1_LogChComb_0,
 	/*
 	 * GSM_PCHAN_TCH_F_PDCH and GSM_PCHAN_TCH_F_TCH_H_PDCH should not be
 	 * part of this, only "real" pchan values will be looked up here.
 	 * See the callers of ts_connect_as().
 	 */
@@ -521,7 +521,7 @@
 	GsmL1_MphConnectReq_t *cr;
 
 	if (pchan == GSM_PCHAN_TCH_F_PDCH
-	    || pchan == GSM_PCHAN_TCH_F_TCH_H_PDCH) {
+	    || pchan == GSM_PCHAN_OSMO_DYN) {
 		LOGP(DL1C, LOGL_ERROR,
 		     "%s Requested TS connect as %s,"
 		     " expected a specific pchan instead\n",
@@ -546,7 +546,7 @@
 {
 	enum gsm_phys_chan_config pchan = ts->pchan;
 	switch (pchan) {
-	case GSM_PCHAN_TCH_F_TCH_H_PDCH:
+	case GSM_PCHAN_OSMO_DYN:
 		ts->dyn.pchan_is = ts->dyn.pchan_want = GSM_PCHAN_NONE;
 		/* First connect as NONE, until first RSL CHAN ACT. */
 		pchan = GSM_PCHAN_NONE;
@@ -581,7 +581,7 @@
 {
 	enum gsm_phys_chan_config pchan = lchan->ts->pchan;
 
-	if (pchan == GSM_PCHAN_TCH_F_TCH_H_PDCH)
+	if (pchan == GSM_PCHAN_OSMO_DYN)
 		pchan = lchan->ts->dyn.pchan_want;
 
 	switch (pchan) {
@@ -601,7 +601,7 @@
 	case GSM_PCHAN_TCH_F_PDCH:
 	case GSM_PCHAN_UNKNOWN:
 	default:
 	/* case GSM_PCHAN_TCH_F_TCH_H_PDCH: is caught above */
 		return GsmL1_SubCh_NA;
 	}
 
@@ -90,7 +90,7 @@
 	[GSM_PCHAN_UNKNOWN]		= GsmL1_LogChComb_0,
 	/*
-	 * GSM_PCHAN_TCH_F_PDCH and GSM_PCHAN_TCH_F_TCH_H_PDCH should not be
+	 * GSM_PCHAN_TCH_F_PDCH and GSM_PCHAN_OSMO_DYN should not be
 	 * part of this, only "real" pchan values will be looked up here.
 	 * See the callers of ts_connect_as().
@@ -601,7 +601,7 @@
 	case GSM_PCHAN_UNKNOWN:
 	default:
-	/* case GSM_PCHAN_TCH_F_TCH_H_PDCH: is caught above */
+	/* case GSM_PCHAN_OSMO_DYN: is caught above */
 		return GsmL1_SubCh_NA;
 	}
-- 
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/24799
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: Ia617d20fc52f09dbab8f4516c06fa1efac08e898
Gerrit-Change-Number: 24799
Gerrit-PatchSet: 4
Gerrit-Owner: pespin <pespin at sysmocom.de>
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel <dwillmann at sysmocom.de>
Gerrit-Reviewer: fixeria <vyanitskiy at sysmocom.de>
Gerrit-Reviewer: laforge <laforge at osmocom.org>
Gerrit-Reviewer: neels <nhofmeyr at sysmocom.de>
Gerrit-Reviewer: pespin <pespin at sysmocom.de>
Gerrit-MessageType: merged
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.osmocom.org/pipermail/gerrit-log/attachments/20210705/3f45f840/attachment.htm>


More information about the gerrit-log mailing list